@@ -9,13 +9,13 @@ use Readonly;
 use Roman;
 use Unicode::UTF8 qw(decode_utf8 encode_utf8);
 
-Readonly::Array our @EXPORT_OK => qw(clean_cover clean_date clean_edition_number
+Readonly::Array our @EXPORT_OK => qw(clean_cover clean_date clean_issn clean_edition_number
 	clean_number_of_pages clean_oclc clean_publication_date clean_publisher_name
 	clean_publisher_place clean_series_name clean_series_ordinal clean_subtitle
 	clean_title look_for_external_id);
 Readonly::Array our @COVERS => qw(hardback paperback);
 
-our $VERSION = 0.20;
+our $VERSION = 0.21;
 our $DEBUG = 0;
 
 sub clean_cover {
@@ -184,6 +184,7 @@ sub clean_edition_number {
 	$ret_edition_number =~ s/\s*$re//ms;
 	$re = decode_utf8('V této');
 	$ret_edition_number =~ s/\s*$re//ms;
+	$ret_edition_number =~ s/\s*V\stomto\ssouboru//ms;
 	$re = decode_utf8('podobě');
 	$ret_edition_number =~ s/\s*$re//ms;
 
@@ -256,6 +257,26 @@ sub clean_edition_number {
 	return $ret_edition_number;
 }
 
+sub clean_issn {
+	my $issn = shift;
+
+	if (! defined $issn) {
+		return;
+	}
+
+	my $ret_issn = $issn;
+	$ret_issn =~ s/\s+;?$//ms;
+
+	if ($ret_issn !~ m/^\d{4}-\d{4}$/ms) {
+		if ($DEBUG) {
+			warn "ISSN '$ret_issn' couldn't clean.";
+		}
+		$ret_issn = undef;
+	}
+
+	return $ret_issn;
+}
+
 sub clean_number_of_pages {
 	my $number_of_pages = shift;
 
@@ -450,6 +471,7 @@ sub clean_series_name {
 
 	$ret_series_name =~ s/\s*;$//g;
 	$ret_series_name =~ s/\s*:$//g;
+	$ret_series_name =~ s/\s*,$//g;
 
 	# Remove [] on begin and end.
 	$ret_series_name = _remove_square_brackets($ret_series_name);
@@ -578,12 +600,13 @@ MARC::Convert::Wikidata::Utils - Utilities for MARC::Convert::Wikidata.
 
 =head1 SYNOPSIS
 
- use MARC::Convert::Wikidata::Utils qw(clean_cover clean_date clean_edition_number clean_number_of_pages clean_oclc clean_publication_date clean_publisher_name clean_publisher_place clean_series_name clean_series_ordinal clean_subtitle clean_title look_for_external_id);
+ use MARC::Convert::Wikidata::Utils qw(clean_cover clean_date clean_edition_number clean_issn clean_number_of_pages clean_oclc clean_publication_date clean_publisher_name clean_publisher_place clean_series_name clean_series_ordinal clean_subtitle clean_title look_for_external_id);
 
  my $cleaned_cover = clean_cover($cover);
  my $cleaned_date = clean_date($date);
  my ($cleaned_date, $options_hr) = clean_date($date);
  my $cleaned_edition_number = clean_edition_number($edition_number);
+ my $cleaned_issn = clean_issn($issn);
  my $cleaned_number_of_pages = clean_number_of_pages($number_of_pages);
  my $cleaned_oclc = clean_oclc($oclc);
  my ($cleaned_publication_date, $option) = clean_publication_date($publication_date);
@@ -624,6 +647,14 @@ Clean edition number in Czech language.
 
 Returns string or undef.
 
+=head2 C<clean_issn>
+
+ my $cleaned_issn = clean_issn($issn);
+
+Clean ISSN.
+
+Returns string or undef.
+
 =head2 C<clean_number_of_pages>
 
  my $cleaned_number_of_pages = clean_number_of_pages($number_of_pages);
@@ -771,6 +802,26 @@ Returns strings.
 
 =head1 EXAMPLE4
 
+=for comment filename=clean_issn.pl
+
+ use strict;
+ use warnings;
+
+ use MARC::Convert::Wikidata::Utils qw(clean_issn);
+
+ my $issn = '0585-5675 ;';
+ my $cleaned_issn = clean_issn($issn);
+
+ # Print out.
+ print "ISSN: $issn\n";
+ print "Cleaned ISSN: $cleaned_issn\n";
+
+ # Output:
+ # ISSN: 0585-5675 ;
+ # Cleaned ISSN: 0585-5675
+
+=head1 EXAMPLE5
+
 =for comment filename=clean_number_of_pages.pl
 
  use strict;
@@ -815,6 +866,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.20
+0.21
 
 =cut
